@@ -785,7 +785,7 @@ def test_get_revision_field_headers():
     # a field header. Set these to a non-empty value.
     request = revision.GetRevisionRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.get_revision), "__call__") as call:
@@ -801,7 +801,7 @@ def test_get_revision_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "name=name/value",
+        "name=name_value",
     ) in kw["metadata"]
 
 
@@ -815,7 +815,7 @@ async def test_get_revision_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = revision.GetRevisionRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.get_revision), "__call__") as call:
@@ -831,7 +831,7 @@ async def test_get_revision_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "name=name/value",
+        "name=name_value",
     ) in kw["metadata"]
 
 
@@ -1013,7 +1013,7 @@ def test_list_revisions_field_headers():
     # a field header. Set these to a non-empty value.
     request = revision.ListRevisionsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_revisions), "__call__") as call:
@@ -1029,7 +1029,7 @@ def test_list_revisions_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "parent=parent/value",
+        "parent=parent_value",
     ) in kw["metadata"]
 
 
@@ -1043,7 +1043,7 @@ async def test_list_revisions_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = revision.ListRevisionsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_revisions), "__call__") as call:
@@ -1061,7 +1061,7 @@ async def test_list_revisions_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "parent=parent/value",
+        "parent=parent_value",
     ) in kw["metadata"]
 
 
@@ -1192,7 +1192,7 @@ def test_list_revisions_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, revision.Revision) for i in results)
 
@@ -1427,7 +1427,7 @@ def test_delete_revision_field_headers():
     # a field header. Set these to a non-empty value.
     request = revision.DeleteRevisionRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.delete_revision), "__call__") as call:
@@ -1443,7 +1443,7 @@ def test_delete_revision_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "name=name/value",
+        "name=name_value",
     ) in kw["metadata"]
 
 
@@ -1457,7 +1457,7 @@ async def test_delete_revision_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = revision.DeleteRevisionRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.delete_revision), "__call__") as call:
@@ -1475,7 +1475,7 @@ async def test_delete_revision_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "name=name/value",
+        "name=name_value",
     ) in kw["metadata"]
 
 
